package App::WordPressTools;
our $VERSION = '1.01';

# eventually we should refactor some code out of the script into modules like this

=head1 NAME

App::WordPressTools - tools to backup and upgrade WordPress installations

=head1 DESCRIPTION

This module is part of the WordPress Tools package. For information about how to install and use the command-line
program, see L<wp-tools>.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Bluehost Inc.

This is free software, licensed under:

The GNU General Public License, Version 2, June 1991

=cut

1;
